Struct TypstHtmlDocument
pub struct TypstHtmlDocument { /* private fields */ }Expand description
An HTML document.
Unlike the PagedDocument, this does not implement Hash because the HTML
introspector is neither hashable nor guaranteed to be 100% derived from the
output (due to the presence of root_mut which is used for cross-linking).
Implementations
impl HtmlDocument
impl HtmlDocument
pub fn new(output: HtmlOutput, info: DocumentInfo) -> HtmlDocument
pub fn new(output: HtmlOutput, info: DocumentInfo) -> HtmlDocument
Creates a new paged document from its parts.
Internally builds the introspector.
pub fn root(&self) -> &HtmlElement
pub fn root(&self) -> &HtmlElement
The document’s root HTML element.
pub fn root_mut(&mut self) -> &mut HtmlElement
pub fn root_mut(&mut self) -> &mut HtmlElement
The document’s root HTML element, mutably.
Technically, mutating the root can mess up the introspector. This should be fixed at some point (https://github.com/typst/typst/issues/7951).
pub fn root_node(&self) -> &HtmlNode
pub fn root_node(&self) -> &HtmlNode
The document’s root HTML element, in its containing node wrapper.
pub fn info_mut(&mut self) -> &mut DocumentInfo
pub fn info_mut(&mut self) -> &mut DocumentInfo
Details about the document, mutably.
pub fn introspector(&self) -> &Arc<HtmlIntrospector>
pub fn introspector(&self) -> &Arc<HtmlIntrospector>
Provides the ability to execute queries on the document.
pub fn introspector_mut(&mut self) -> &mut HtmlIntrospector
pub fn introspector_mut(&mut self) -> &mut HtmlIntrospector
Provides the ability to execute queries on the document.